@@ -74,11 +74,12 @@ class Domoticz(IPlugin):
 		if jsonInput['outcome']['entities']['local_search_query']['value'] :
 			local = jsonInput['outcome']['entities']['local_search_query']['value']
 		else:
-			bodies = "pas de local_search_query"
+			local = "pas de local_search_query"
+			bodies = " pas de parametres secondaires"
 #
 		idex= local + " " + location +  "_"
 		log.msg("index :  %s" % (idex))		
-		log.msg("self.configuration_plugin['param_dz']:  %s" % (self.configuration_plugin['param_dz']))		
+#		log.msg("self.configuration_plugin['param_dz']:  %s" % (self.configuration_plugin['param_dz']))		
 		for rs in self.configuration_plugin['param_dz']:
 			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
